@@ -1,5 +1,5 @@
 /* This file is part of the GNU plotutils package.  Copyright (C) 1995,
-   1996, 1997, 1998, 1999, 2000, 2005, Free Software Foundation, Inc.
+   1996, 1997, 1998, 1999, 2000, 2005, 2008, Free Software Foundation, Inc.
 
    The GNU plotutils package is free software.  You may redistribute it
    and/or modify it under the terms of the GNU General Public License as
@@ -34,8 +34,8 @@
    `pl_libplot_ver'.  The PL_LIBPLOT_VER macro is not compiled into it.
    Both are available to applications that include this header file. */
 
-#define PL_LIBPLOT_VER_STRING "4.2"
-#define PL_LIBPLOT_VER         402
+#define PL_LIBPLOT_VER_STRING "4.3"
+#define PL_LIBPLOT_VER         403
 
 extern const char pl_libplot_ver[8];   /* need room for 99.99aa */
 
